import { EventEmitter } from 'events';
interface Events<T> {
    /** When an element is set (added or overwritten) */
    on(event: 'set', listener: (element: T, index: number) => void): this;
    once(event: 'set', listener: (element: T, index: number) => void): this;
    emit(event: 'set', element: T, index: number): boolean;
    /** When an element is removed (explicitly removed - overwritten does not trigger this) */
    on(event: 'remove', listener: (element: T, index: number) => void): this;
    once(event: 'remove', listener: (element: T, index: number) => void): this;
    emit(event: 'remove', element: T, index: number): boolean;
}
/** A dictionary-like class that emits events */
export declare class EventedDictionary<T> extends EventEmitter implements Events<T> {
    private data;
    private count;
    /**
     * Check if a given key is in use
     * @param key Key to check if used
     */
    exists(key: string): boolean;
    /**
     * Get the element of a given key
     * @param key Key of the element
     */
    get(key: string): T;
    /**
     * Set the element of a given key (adds the element)
     * @param key Desired key of the element
     * @param element Element to set
     */
    set(key: string, element: T): T;
    /**
     * Remove an element
     * @param key Key of the element
     */
    remove(key: string): boolean;
    /**
     * Get the number of key/element pairs
     */
    getCount(): number;
    /**
     * Call a function for each key/element pair
     * @param callback callback(element, key)
     */
    forEach(callback: (element: T, key: string) => void): void;
}
export {};
