"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var events_1 = require("events");
/** A dictionary-like class that emits events */
var EventedDictionary = /** @class */ (function (_super) {
    __extends(EventedDictionary, _super);
    function EventedDictionary() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.data = {};
        _this.count = 0;
        return _this;
    }
    /**
     * Check if a given key is in use
     * @param key Key to check if used
     */
    EventedDictionary.prototype.exists = function (key) {
        return Object.prototype.hasOwnProperty.call(this.data, key);
    };
    /**
     * Get the element of a given key
     * @param key Key of the element
     */
    EventedDictionary.prototype.get = function (key) {
        return this.data[key];
    };
    /**
     * Set the element of a given key (adds the element)
     * @param key Desired key of the element
     * @param element Element to set
     */
    EventedDictionary.prototype.set = function (key, element) {
        // Increment count if key was not already in use
        if (!Object.prototype.hasOwnProperty.call(this.data, key)) {
            this.count++;
        }
        this.data[key] = element; // Set the element of the key
        this.emit('set', element, key); // Emit event
        return element; // Success
    };
    /**
     * Remove an element
     * @param key Key of the element
     */
    EventedDictionary.prototype.remove = function (key) {
        // Check if key is not present in data object
        if (!Object.prototype.hasOwnProperty.call(this.data, key)) {
            return false;
        }
        this.count -= 1; // Decrement count
        var element = this.data[key]; // Get element
        delete this.data[key]; // Remove element / key pair from data
        this.emit('remove', element, key); // Emit event
        return true; // Success
    };
    /**
     * Get the number of key/element pairs
     */
    EventedDictionary.prototype.getCount = function () {
        return this.count;
    };
    /**
     * Call a function for each key/element pair
     * @param callback callback(element, key)
     */
    EventedDictionary.prototype.forEach = function (callback) {
        for (var key in this.data) {
            callback(this.data[key], key);
        }
    };
    return EventedDictionary;
}(events_1.EventEmitter));
exports.EventedDictionary = EventedDictionary;
//# sourceMappingURL=EventedDictionary.js.map