import { EventEmitter } from 'events';
interface Events<T> {
    /** When an element is added */
    on(event: 'add', listener: (element: T, index: number) => void): this;
    once(event: 'add', listener: (element: T, index: number) => void): this;
    emit(event: 'add', element: T, index: number): boolean;
    /** When an element is removed */
    on(event: 'remove', listener: (element: T, index: number) => void): this;
    once(event: 'remove', listener: (element: T, index: number) => void): this;
    emit(event: 'remove', element: T, index: number): boolean;
}
/** An array-like class that emits events */
export declare class EventedList<T> extends EventEmitter implements Events<T> {
    private data;
    /**
     * Get the element of a given index (or undefined if not found)
     * @param index Elements index
     */
    get(index: number): T;
    /**
     * Add an element to the end of the list
     * @param element Element to add
     */
    push(element: T): T;
    /**
     * Remove an element from the list
     * (Only the first occurrence is removed - lowest index first)
     * @param element Element to remove
     * @returns {boolean} If an element was removed
     */
    remove(element: T): boolean;
    /**
     * Remove an element with a given index
     * @param index Index of element to remove
     * @returns {boolean} If an element was removed
     */
    removeAt(index: number): boolean;
    /**
     * Remove all elements from the list
     */
    clear(): void;
    /**
     * Get the number of elements in the list
     * @returns {number} Number of elements in list
     */
    getLength(): number;
    /**
     * Copy the underlying array
     */
    copyData(): Array<T>;
    /**
     * Copy this evented list (Copy has no event listeners)
     * @returns {EventedList<T>} Copy of this
     */
    copy(): EventedList<T>;
    forEach(func: (value: T, index: number) => void): void;
    indexOf(searchElement: T, fromIndex?: number): number;
    some(func: (value: T, index: number) => boolean, thisArg?: any): boolean;
}
export {};
