"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var events_1 = require("events");
/** An array-like class that emits events */
var EventedList = /** @class */ (function (_super) {
    __extends(EventedList, _super);
    function EventedList() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.data = new Array();
        return _this;
    }
    /**
     * Get the element of a given index (or undefined if not found)
     * @param index Elements index
     */
    EventedList.prototype.get = function (index) {
        return this.data[index | 0];
    };
    /**
     * Add an element to the end of the list
     * @param element Element to add
     */
    EventedList.prototype.push = function (element) {
        this.data.push(element); // Push element onto the array
        this.emit('add', element, this.data.length - 1); // Emit event
        return element;
    };
    /**
     * Remove an element from the list
     * (Only the first occurrence is removed - lowest index first)
     * @param element Element to remove
     * @returns {boolean} If an element was removed
     */
    EventedList.prototype.remove = function (element) {
        var index = this.data.indexOf(element); // Get index of element
        if (index === -1) {
            return false;
        } // Check if element was not found
        this.data.splice(index, 1); // Remove element from array
        this.emit('remove', element, index); // Emit event
        return true; // Success
    };
    /**
     * Remove an element with a given index
     * @param index Index of element to remove
     * @returns {boolean} If an element was removed
     */
    EventedList.prototype.removeAt = function (index) {
        if (index < 0 || index > this.getLength()) {
            return false;
        } // Check if index is out of bounds
        var element = this.data[index]; // Get element (so it can later be sent in the event)
        this.data.splice(index, 1); // Remove element from array
        this.emit('remove', element, index); // Emit event
        return true; // Success
    };
    /**
     * Remove all elements from the list
     */
    EventedList.prototype.clear = function () {
        var length = this.data.length;
        for (var i = 0; i < length; i++) {
            this.removeAt(0);
        }
    };
    /**
     * Get the number of elements in the list
     * @returns {number} Number of elements in list
     */
    EventedList.prototype.getLength = function () {
        return this.data.length;
    };
    /**
     * Copy the underlying array
     */
    EventedList.prototype.copyData = function () {
        return this.data.slice(0);
    };
    /**
     * Copy this evented list (Copy has no event listeners)
     * @returns {EventedList<T>} Copy of this
     */
    EventedList.prototype.copy = function () {
        var list = new EventedList();
        list.data = this.copyData();
        return list;
    };
    // -- Wrapped Array Methods -- //
    EventedList.prototype.forEach = function (func) {
        return this.data.forEach(func);
    };
    EventedList.prototype.indexOf = function (searchElement, fromIndex) {
        return this.data.indexOf(searchElement, fromIndex);
    };
    EventedList.prototype.some = function (func, thisArg) {
        return this.data.some(func, thisArg);
    };
    return EventedList;
}(events_1.EventEmitter));
exports.EventedList = EventedList;
//# sourceMappingURL=EventedList.js.map