/**
 * 2D Vector
 * @class Point
 * @property {Number} x
 * @property {Number} y
 */
export declare class Point implements IPoint {
    x: number;
    y: number;
    /**
     * Constructor
     * @param {Number} x X value (optional)
     * @param {Number} y Y value (optional)
     */
    constructor(x?: number, y?: number);
    /**
     * Calculates the distance to the origin.
     * @return {Number} Distance to origin
     */
    length(): number;
    /**
     * Set the X and Y of this point.
     * @param {Number} x X
     * @param {Number} y Y
     * @return {Point} this
     */
    set(x: number, y: number): Point;
    /**
     * Moves the point by some amount.
     * @param {Number} x X movement
     * @param {Number} y Y movement
     * @return {Point} this
     */
    shift(x: number, y: number): Point;
    /**
     * Scales the point by some amount.
     * @param {Number} xOrBoth X scalar
     * @param {Number} y Y scalar
     * @return {Point} this
     */
    scale(xOrBoth: number, y?: number): Point;
    /**
     * Normalizes this point.
     * Effectively makes this the length of 1 unit but keeps the direction unchanged.
     * (Extremely small rounding errors will most likey occur, due to the way Number works)
     *
     * __Note:  To get a new point with the normal, use ".clone().normalize()" instead__
     * @return {Point} this
     */
    normalize(): Point;
    /**
     * Rotates the point around the origin.
     * (Extremely small rounding errors will most likey occur, due to the way Number works)
     * @param {Number} rotation Amount to rotate (Clockwise in radians)
     * @return {Point} this
     */
    rotate(rotation: number): Point;
    /**
     * Copy the X and Y from another point.
     * @param {Point} source Point to copy X & Y from
     * @return {Point} this
     */
    copy(source: IPoint): Point;
    /**
     * Creates a copy of this (a new point with the same X and Y values).
     * @return {Point} Copy of this
     */
    clone(): Point;
    /**
     * Creates a string representation of this Point
     * @returns String of this point
     */
    toString(): string;
}
/**
 * Any object that can be used as a Point
 */
export interface IPoint {
    x: number;
    y: number;
}
