import { Point } from './Point';
/**
 * Arbitrary collection of Points
 * (More or less an array wrapper with helpful methods)
 */
export declare class PointCloud {
    /**
     * Points in this point cloud
     */
    points: Point[];
    constructor(points?: Point[]);
    /**
     * Calculate the average of all points
     */
    average(): Point;
    /**
     * Calculate the center of this point could
     * (The average of the outer-most points of this cloud)
     */
    center(): Point;
    /**
     * Shift all points in this could
     * @param x X difference
     * @param y Y difference
     * @return {PointCloud} This (enables chaining)
     */
    shift(x: number, y: number): PointCloud;
    /**
     * Scale all of the points in this cloud
     * @param {Number} xOrBoth X scalar
     * @param {Number} y Y scalar
     * @return {Point} this
     */
    scale(xOrBoth: number, y?: number): PointCloud;
    /**
     * Create a clone of this point cloud
     * @param clonePoints If the clone should have points of it own, instead of using the same points as this
     */
    clone(clonePoints?: boolean): PointCloud;
}
