"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Point_1 = require("./Point");
/**
 * Arbitrary collection of Points
 * (More or less an array wrapper with helpful methods)
 */
var PointCloud = /** @class */ (function () {
    function PointCloud(points) {
        /**
         * Points in this point cloud
         */
        this.points = [];
        if (points) {
            for (var _i = 0, points_1 = points; _i < points_1.length; _i++) {
                var point = points_1[_i];
                if (point) {
                    this.points.push(point);
                }
            }
        }
    }
    /**
     * Calculate the average of all points
     */
    PointCloud.prototype.average = function () {
        var sum = new Point_1.Point();
        for (var _i = 0, _a = this.points; _i < _a.length; _i++) {
            var point = _a[_i];
            sum.shift(point.x, point.y);
        }
        return sum.scale(1 / this.points.length);
    };
    /**
     * Calculate the center of this point could
     * (The average of the outer-most points of this cloud)
     */
    PointCloud.prototype.center = function () {
        var minX, maxX, minY, maxY;
        minX = minY = Number.POSITIVE_INFINITY;
        maxX = maxY = Number.NEGATIVE_INFINITY;
        for (var _i = 0, _a = this.points; _i < _a.length; _i++) {
            var point = _a[_i];
            if (point.x > maxX) {
                maxX = point.x;
            }
            else if (point.x < minX) {
                minX = point.x;
            }
            if (point.y > maxY) {
                maxY = point.y;
            }
            else if (point.y < minY) {
                minY = point.y;
            }
        }
        return new Point_1.Point((minX + maxX) * 0.5, (minY + maxY) * 0.5);
    };
    /**
     * Shift all points in this could
     * @param x X difference
     * @param y Y difference
     * @return {PointCloud} This (enables chaining)
     */
    PointCloud.prototype.shift = function (x, y) {
        for (var _i = 0, _a = this.points; _i < _a.length; _i++) {
            var point = _a[_i];
            point.shift(x, y);
        }
        return this;
    };
    /**
     * Scale all of the points in this cloud
     * @param {Number} xOrBoth X scalar
     * @param {Number} y Y scalar
     * @return {Point} this
     */
    PointCloud.prototype.scale = function (xOrBoth, y) {
        if (y === undefined) {
            y = xOrBoth;
        }
        for (var _i = 0, _a = this.points; _i < _a.length; _i++) {
            var point = _a[_i];
            point.scale(xOrBoth, y);
        }
        return this;
    };
    /**
     * Create a clone of this point cloud
     * @param clonePoints If the clone should have points of it own, instead of using the same points as this
     */
    PointCloud.prototype.clone = function (clonePoints) {
        if (clonePoints === void 0) { clonePoints = true; }
        if (clonePoints) {
            var points = [];
            for (var _i = 0, _a = this.points; _i < _a.length; _i++) {
                var point = _a[_i];
                points.push(point.clone());
            }
            return new PointCloud(points);
        }
        else {
            return new PointCloud(this.points);
        }
    };
    return PointCloud;
}());
exports.PointCloud = PointCloud;
//# sourceMappingURL=PointCloud.js.map