/**
 * 2D Rectangle
 * @class Rectangle
 * @property {Number} left Position of the rectangles left side
 * @property {Number} top Position of the rectangles top
 * @property {Number} right Position of the rectangles right side
 * @property {Number} bottom Position of the rectangles bottom
 */
export declare class Rectangle implements IRectangle {
    left: number;
    top: number;
    right: number;
    bottom: number;
    /**
     * Create a rectangle
     * @param left Position of the rectangles left side
     * @param top Position of the rectangles top
     * @param right Position of the rectangles right side
     * @param bottom Position of the rectangles bottom
     */
    constructor(left?: number, top?: number, right?: number, bottom?: number);
    /**
     * Shift the position of this rectangle by some amount
     * @param horizontal Amount to shift horizontally (left/right)
     * @param vertical Amount to shift vertically (up/down)
     */
    shift(horizontal: number, vertical: number): Rectangle;
    /**
     * @TODO
     */
    moveTo(left: number, top: number): Rectangle;
    /**
     * Get the width of the rectangle
     * @returns Width of the rectangle
     */
    getWidth(): number;
    /**
     * Get the height of the rectangle
     * @returns Height of the rectangle
     */
    getHeight(): number;
    /**
     * Get the area of the rectangle
     * @returns Area of the rectangle
     */
    getArea(): number;
    /**
     * Get the intersecting area of this rectangle and another
     * (returns null if no intersection was made)
     * @param other Rectangle to check intersection with
     * @return A new rectangle of the intersecting area (null if no intersection was made)
     */
    intersection(other: Rectangle): Rectangle | null;
    /**
     * Check if this rectangle intersects with anther
     * @param other Rectangle to check intersection with
     * @returns If the rectangles intersected
     */
    isIntersecting(other: IRectangle): boolean;
    /**
     * Creates a copy of this rectangle
     * @returns Copy of this rectangle
     */
    clone(): Rectangle;
}
export interface IRectangle {
    left: number;
    top: number;
    right: number;
    bottom: number;
}
