"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * 2D Rectangle
 * @class Rectangle
 * @property {Number} left Position of the rectangles left side
 * @property {Number} top Position of the rectangles top
 * @property {Number} right Position of the rectangles right side
 * @property {Number} bottom Position of the rectangles bottom
 */
var Rectangle = /** @class */ (function () {
    /**
     * Create a rectangle
     * @param left Position of the rectangles left side
     * @param top Position of the rectangles top
     * @param right Position of the rectangles right side
     * @param bottom Position of the rectangles bottom
     */
    function Rectangle(left, top, right, bottom) {
        if (left === void 0) { left = 0; }
        if (top === void 0) { top = 0; }
        if (right === void 0) { right = 0; }
        if (bottom === void 0) { bottom = 0; }
        this.left = left;
        this.top = top;
        this.right = right;
        this.bottom = bottom;
    }
    /**
     * Shift the position of this rectangle by some amount
     * @param horizontal Amount to shift horizontally (left/right)
     * @param vertical Amount to shift vertically (up/down)
     */
    Rectangle.prototype.shift = function (horizontal, vertical) {
        this.left += horizontal;
        this.right += horizontal;
        this.top += vertical;
        this.bottom += vertical;
        return this;
    };
    /**
     * @TODO
     */
    Rectangle.prototype.moveTo = function (left, top) {
        // Move "right" relative to "left", so that the height is the same
        this.right = this.right - this.left + left;
        this.left = left;
        // Move "bottom" relative to "top", so that the height is the same
        this.bottom = this.bottom - this.top + top;
        this.top = top;
        return this;
    };
    /**
     * Get the width of the rectangle
     * @returns Width of the rectangle
     */
    Rectangle.prototype.getWidth = function () {
        return this.right - this.left;
    };
    /**
     * Get the height of the rectangle
     * @returns Height of the rectangle
     */
    Rectangle.prototype.getHeight = function () {
        return this.bottom - this.top;
    };
    /**
     * Get the area of the rectangle
     * @returns Area of the rectangle
     */
    Rectangle.prototype.getArea = function () {
        return (this.right - this.left) * (this.bottom - this.top);
    };
    /**
     * Get the intersecting area of this rectangle and another
     * (returns null if no intersection was made)
     * @param other Rectangle to check intersection with
     * @return A new rectangle of the intersecting area (null if no intersection was made)
     */
    Rectangle.prototype.intersection = function (other) {
        var rect = new Rectangle(Math.max(this.left, other.left), Math.min(this.top, other.top), Math.max(this.right, other.right), Math.min(this.bottom, other.bottom));
        if (rect.getArea() > 0) {
            return rect;
        }
        return null;
    };
    /**
     * Check if this rectangle intersects with anther
     * @param other Rectangle to check intersection with
     * @returns If the rectangles intersected
     */
    Rectangle.prototype.isIntersecting = function (other) {
        if (this.left > other.right ||
            this.top > other.bottom ||
            this.right < other.left ||
            this.bottom < other.top) {
            return false;
        }
        return true;
    };
    /**
     * Creates a copy of this rectangle
     * @returns Copy of this rectangle
     */
    Rectangle.prototype.clone = function () {
        return new Rectangle(this.left, this.right, this.top, this.bottom);
    };
    return Rectangle;
}());
exports.Rectangle = Rectangle;
//# sourceMappingURL=Rectangle.js.map