/**
 * Random number generator (with private seed)
 */
export class Random {
  private _seed: number;
  
  constructor(seed?: number) {
    if (seed === undefined) { seed = Math.random() * 2147483647; }
    this._seed = seed % 2147483647;
    if (this._seed <= 0) this._seed += 2147483646;
  }

  /**
   * Returns a pseudo-random value between 1 and 2^32 - 2.
   */
  public next(): number {
    return this._seed = this._seed * 16807 % 2147483647;
  }

  /**
   * Generates a pseudo-random floating point number in range [0, 1).
   */
  public nextFloat(): number {
    // We know that result of next() will be 1 to 2147483646 (inclusive).
    return (this.next() - 1) / 2147483646;
  }
}
